==> react-numeric-input-2.0.9.tgz: package/CHANGELOG.md <==
2.0.9
--------------------------------------------------------------------------------
* Field now accepts `"-."`, `"+.`", `"."`, `"-"`, and `"+"` at beginning of input value.
* Merge some pull requests
* Fixed backspace on float values
* Use external prop-types package
* Use react and react-dom v15.6.1

2.0.8
--------------------------------------------------------------------------------
Fixed `React.PropTypes` reference warnings

2.0.7
--------------------------------------------------------------------------------
* Fixed the focus/blur issues. Thanks to https://github.com/vlad-ignatov/react-numeric-input/pull/25
* onChange gets called when input content is deleted #27

2.0.6
--------------------------------------------------------------------------------
* Use peerDependencies to specify the react versions


2.0.5
--------------------------------------------------------------------------------
* Compatible with React 15.2 and 15.3
* Preserve the selection between re-rendering
* Fix a bug in handling the step prop
* Loose formatting while the user is typing and strict on blur
* Various other fixes

2.0.4
--------------------------------------------------------------------------------
* Make it compatible with React 15
* Inline styles can be disabled by passing style={false}
* Various small fixes and improvements


2.0.3
--------------------------------------------------------------------------------
* Provide more useful data to event callbacks like onChange, onInvalid etc.
* Make sure that onBlur, onFocus and onKeyDown are called the same way React would
call them.


2.0.2
--------------------------------------------------------------------------------
* Add support for callback props onChange, onInvalid, onValid and more...
* defaultValue can also be used instead of value
* Make use of HTML5 input validation if available


2.0.1
--------------------------------------------------------------------------------
* Move react and react-dom to devDependencies so that npm does not install them


2.0.0
--------------------------------------------------------------------------------
* Switch to inline styles
* Better integration with external scripts
* Better integration with build tools
* Support for touch devices


1.0.0
--------------------------------------------------------------------------------
* Initial release

==> react-numeric-input-2.1.0.tgz: package/CHANGELOG.md <==
2.1.0
--------------------------------------------------------------------------------
* Added `snap` prop to make the value snap to the closest step when using buttons or up/down keys to change it.
* Pass a reference to the input element to the onChange callbacks
* Fixed an issue preventing the input from being editable when it's entire value is selected
* Fixed an issue that might cause the component to loose its value if re-rendered without value prop


2.0.9
--------------------------------------------------------------------------------
* Field now accepts `"-."`, `"+.`", `"."`, `"-"`, and `"+"` at beginning of input value.
* Merge some pull requests
* Fixed backspace on float values
* Use external prop-types package
* Use react and react-dom v15.6.1

2.0.8
--------------------------------------------------------------------------------
* Fixed `React.PropTypes` reference warnings

2.0.7
--------------------------------------------------------------------------------
* Fixed the focus/blur issues. Thanks to https://github.com/vlad-ignatov/react-numeric-input/pull/25
* onChange gets called when input content is deleted #27

2.0.6
--------------------------------------------------------------------------------
* Use peerDependencies to specify the react versions


2.0.5
--------------------------------------------------------------------------------
* Compatible with React 15.2 and 15.3
* Preserve the selection between re-rendering
* Fix a bug in handling the step prop
* Loose formatting while the user is typing and strict on blur
* Various other fixes

2.0.4
--------------------------------------------------------------------------------
* Make it compatible with React 15
* Inline styles can be disabled by passing style={false}
* Various small fixes and improvements


2.0.3
--------------------------------------------------------------------------------
* Provide more useful data to event callbacks like onChange, onInvalid etc.
* Make sure that onBlur, onFocus and onKeyDown are called the same way React would
call them.


2.0.2
--------------------------------------------------------------------------------
* Add support for callback props onChange, onInvalid, onValid and more...
* defaultValue can also be used instead of value
* Make use of HTML5 input validation if available


2.0.1
--------------------------------------------------------------------------------
* Move react and react-dom to devDependencies so that npm does not install them


2.0.0
--------------------------------------------------------------------------------
* Switch to inline styles
* Better integration with external scripts
* Better integration with build tools
* Support for touch devices


1.0.0
--------------------------------------------------------------------------------
* Initial release
